@@ -18,6 +18,7 @@ package org.apache.jackrabbit.core.data;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
@@ -221,6 +222,13 @@ public class ConsistencyCheckerImplTest extends TestCase {
         assertTrue("Expected orphan to be modified", listener.changes.isModified(orphanedId));
     }
 
+    public void testEmptyRepo() throws RepositoryException {
+        List<NodePropBundle> t = Collections.emptyList();
+        MockPersistenceManager pm = new MockPersistenceManager(t);
+        ConsistencyCheckerImpl checker = new ConsistencyCheckerImpl(pm, null, null, null);
+        checker.check(null, false);
+    }
+
     public void testDoubleCheckOrphanedNode() throws RepositoryException {
         NodePropBundle orphaned = new NodePropBundle(new NodeId(0, 1));
         orphaned.setParentId(new NodeId(1, 0));
@@ -452,6 +460,11 @@ public class ConsistencyCheckerImplTest extends TestCase {
             return bundles.get(id);
         }
 
+        @Override
+        public boolean exists(final NodeId id) {
+            return bundles.containsKey(id);
+        }
+
         @Override
         protected void evictBundle(final NodeId id) {
         }
