@@ -32,9 +32,9 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.ServiceLoader;
 import java.util.StringTokenizer;
 
-import javax.imageio.spi.ServiceRegistry;
 import javax.jcr.Binary;
 import javax.jcr.Item;
 import javax.jcr.Node;
@@ -187,7 +187,7 @@ public class JcrUtils {
         log.append(newline);
         log.append("The following RepositoryFactory classes were consulted:");
         Iterator<RepositoryFactory> iterator =
-                ServiceRegistry.lookupProviders(RepositoryFactory.class);
+                ServiceLoader.load(RepositoryFactory.class).iterator();
         while (iterator.hasNext()) {
             RepositoryFactory factory = iterator.next();
             log.append(newline);
@@ -264,7 +264,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over the shared set of the given node.
+     * Returns an {@link Iterable} over the shared set of the given node.
      * <p>
      * The first iterator is acquired directly during this method call to
      * allow a possible {@link RepositoryException} to be thrown as-is.
@@ -298,7 +298,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over the children of the given node.
+     * Returns an {@link Iterable} over the children of the given node.
      * <p>
      * The first iterator is acquired directly during this method call to
      * allow a possible {@link RepositoryException} to be thrown as-is.
@@ -332,7 +332,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over those children of the given node
+     * Returns an {@link Iterable} over those children of the given node
      * that match the given name pattern.
      * <p>
      * The first iterator is acquired directly during this method call to
@@ -369,7 +369,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over those children of the given node
+     * Returns an {@link Iterable} over those children of the given node
      * that match the given name patterns.
      * <p>
      * The first iterator is acquired directly during this method call to
@@ -406,7 +406,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over the properties of the given node.
+     * Returns an {@link Iterable} over the properties of the given node.
      * <p>
      * The first iterator is acquired directly during this method call to
      * allow a possible {@link RepositoryException} to be thrown as-is.
@@ -441,7 +441,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over those properties of the
+     * Returns an {@link Iterable} over those properties of the
      * given node that match the given name pattern.
      * <p>
      * The first iterator is acquired directly during this method call to
@@ -478,7 +478,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over those properties of the
+     * Returns an {@link Iterable} over those properties of the
      * given node that match the given name patterns.
      * <p>
      * The first iterator is acquired directly during this method call to
@@ -515,7 +515,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over references to the given node.
+     * Returns an {@link Iterable} over references to the given node.
      * <p>
      * The first iterator is acquired directly during this method call to
      * allow a possible {@link RepositoryException} to be thrown as-is.
@@ -550,7 +550,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over those references to the
+     * Returns an {@link Iterable} over those references to the
      * given node that have the given name.
      * <p>
      * The first iterator is acquired directly during this method call to
@@ -587,7 +587,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over weak references to the given node.
+     * Returns an {@link Iterable} over weak references to the given node.
      * <p>
      * The first iterator is acquired directly during this method call to
      * allow a possible {@link RepositoryException} to be thrown as-is.
@@ -622,7 +622,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over those weak references to the
+     * Returns an {@link Iterable} over those weak references to the
      * given node that have the given name.
      * <p>
      * The first iterator is acquired directly during this method call to
@@ -659,7 +659,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Node>} over nodes in the given query result.
+     * Returns an {@link Iterable} over nodes in the given query result.
      * <p>
      * The first iterator is acquired directly during this method call to
      * allow a possible {@link RepositoryException} to be thrown as-is.
@@ -694,7 +694,7 @@ public class JcrUtils {
     }
 
     /**
-     * Returns an {@link Iterable<Row>} over nodes in the given query result.
+     * Returns an {@link Iterable} over nodes in the given query result.
      * <p>
      * The first iterator is acquired directly during this method call to
      * allow a possible {@link RepositoryException} to be thrown as-is.
@@ -1448,10 +1448,27 @@ public class JcrUtils {
         if (absolutePath == null || absolutePath.length() == 0 || "/".equals(absolutePath)) {
             // path denotes root node
             return session.getRootNode();
+        } else if (!absolutePath.startsWith("/")) {
+            throw new IllegalArgumentException("not an absolute path: " + absolutePath);
+        } else if (session.nodeExists(absolutePath) && !createUniqueLeaf) {
+            return session.getNode(absolutePath);
+        } else {
+            // find deepest existing parent node
+            String path = absolutePath;
+            int currentIndex = path.lastIndexOf('/');
+            String existingPath = null;
+            while (currentIndex > 0 && existingPath == null) {
+                path = path.substring(0, currentIndex);
+                if (session.nodeExists(path)) {
+                    existingPath = path;
+                } else {
+                    currentIndex = path.lastIndexOf('/');
+                }
+            }
+            // create path relative to the root node
+            return getOrCreateByPath(existingPath == null ? session.getRootNode() : session.getNode(existingPath),
+                    absolutePath.substring(currentIndex + 1), createUniqueLeaf, intermediateNodeType, nodeType, autoSave);
         }
-        // create path relative to the root node
-        return getOrCreateByPath(session.getRootNode(), absolutePath.substring(1),
-                createUniqueLeaf, intermediateNodeType, nodeType, autoSave);
     }
 
     /**
@@ -1543,6 +1560,27 @@ public class JcrUtils {
             return baseNode.getNode(path);
         }
 
+        // find the parent that exists
+        // we can start from the deepest child in tree
+        String fullPath = baseNode.getPath().equals("/") ? "/" + path : baseNode.getPath() + "/" + path;
+        int currentIndex = fullPath.lastIndexOf('/');
+        String temp = fullPath;
+        String existingPath = null;
+        while (currentIndex > 0) {
+            temp = temp.substring(0, currentIndex);
+            // break when first existing parent is found
+            if (baseNode.getSession().itemExists(temp)) {
+                existingPath = temp;
+                break;
+            }
+            currentIndex = temp.lastIndexOf('/');
+        }
+
+        if (existingPath != null) {
+            baseNode = baseNode.getSession().getNode(existingPath);
+            path = fullPath.substring(existingPath.length() + 1);
+        }
+
         Node node = baseNode;
         int pos = path.lastIndexOf('/');
 
