@@ -72,7 +72,6 @@ import org.slf4j.LoggerFactory;
  * <li><a href="#bwrite">Batch write</a></li>
  * </ul>
  * functionality and supports cross workspace copy and cloning.
- * </p>
  * 
  * <h3><a name="bread">Batch Read</a></h3>
  *
@@ -110,7 +109,7 @@ import org.slf4j.LoggerFactory;
  * extracted from the JSON on the client side need some special handling:
  * 
  * <pre>
- * - Node with index > 1, get a JSON key consisting of
+ * - Node with index &gt; 1, get a JSON key consisting of
  *   Node.getName() + "[" + Node.getIndex() + "]" 
  *
  * - Binary Property
@@ -144,7 +143,7 @@ import org.slf4j.LoggerFactory;
  * <p>
  * Example:
  * <pre>
- * $ curl 'http://.../parent.json?:path=child1&:path=child2'
+ * $ curl 'http://.../parent.json?:path=child1&amp;:path=child2'
  * {"nodes":{"/parent/child1":{...},"/parent/child2":{...}}}
  * </pre>
  *
@@ -167,28 +166,28 @@ import org.slf4j.LoggerFactory;
  *   pairs      ::= pair line-end pair | pair line-end pairs
  *   line-end   ::= "\r\n" | "\n" | "\r"
  *   key        ::= diffchar path
- *   diffchar   ::= "+" | "^" | "-" | ">"
+ *   diffchar   ::= "+" | "^" | "-" | "&gt;"
  *   path       ::= abspath | relpath
  *   abspath    ::= * absolute path to an item *
  *   relpath    ::= * relpath from item at request URI to an item *
- *   value      ::= value+ | value- | value^ | value>
+ *   value      ::= value+ | value- | value^ | value&gt;
  *   value+     ::= * a JSON object *
  *   value-     ::= ""
  *   value^     ::= * any JSON value except JSON object *
- *   value>     ::= path | path "#before" | path "#after" | "#first" | "#last"
+ *   value&gt;     ::= path | path "#before" | path "#after" | "#first" | "#last"
  * </pre>
  *
  * In other words:
  * <ul>
  * <li>diff consists of one or more key-value pair(s)</li>
  * <li>key must start with a diffchar followed by a rel. or abs. item path</li>
- * <li>diffchar being any of "+", "^", "-" or ">" representing the transient
+ * <li>diffchar being any of "+", "^", "-" or "&gt;" representing the transient
  * item modifications as follows
  * <pre>
  *   "+" addNode
  *   "^" setProperty / setValue / removeProperty
  *   "-" remove Item
- *   ">" move / reorder Nodes
+ *   "&gt;" move / reorder Nodes
  * </pre>
  * </li>
  * <li>key must be separated from the value by a ":" surrounded by whitespace.</li>
@@ -573,12 +572,6 @@ public abstract class JcrRemotingServlet extends JCRWebdavServerServlet {
     /**
      * TODO: doesn't work properly with intermediate SNS-nodes
      * TODO: doesn't respect jcr:uuid properties.
-     *
-     * @param session
-     * @param targetPath
-     * @param data
-     * @throws RepositoryException
-     * @throws DiffException
      */
     private static String modifyContent(Session session, String targetPath, RequestData data, ProtectedRemoveManager protectedRemoveManager)
             throws RepositoryException, DiffException {
@@ -615,13 +608,6 @@ public abstract class JcrRemotingServlet extends JCRWebdavServerServlet {
         return null; // TODO build loc-href if items were created.
     }
 
-    /**
-     * 
-     * @param session
-     * @param nodePath
-     * @param data
-     * @throws RepositoryException
-     */
     private static void createNode(Session session, String nodePath, RequestData data) throws RepositoryException {
         Node parent = session.getRootNode();
         String[] smgts = Text.explode(nodePath, '/');
@@ -643,12 +629,6 @@ public abstract class JcrRemotingServlet extends JCRWebdavServerServlet {
         }
     }
 
-    /**
-     *
-     * @param request
-     * @return
-     * @throws DavException
-     */
     private static Session getRepositorySession(WebdavRequest request) throws DavException {
         DavSession ds = request.getDavSession();
         return JcrDavSession.getRepositorySession(ds);
@@ -675,8 +655,13 @@ public abstract class JcrRemotingServlet extends JCRWebdavServerServlet {
 
         @Override
         public DavResourceLocator createResourceLocator(String prefix, String href) {
+            return createResourceLocator(prefix, href, false);
+        }
+
+        @Override
+        public DavResourceLocator createResourceLocator(String prefix, String href, boolean forDestination) {
             DavResourceLocator loc = super.createResourceLocator(prefix, href);
-            if (endsWithJson(href)) {
+            if (!forDestination && endsWithJson(href)) {
                 loc = new WrappingLocator(super.createResourceLocator(prefix, href));
             }
             return loc;
