@@ -212,6 +212,11 @@ public abstract class AbstractJCRTest extends JUnitTest {
      */
     protected String mixLockable;
 
+    /**
+     * JCR Name mix:title using the namespace resolver of the current session.
+     */
+    protected String mixTitle;
+
     /**
      * JCR Name mix:shareable using the namespace resolver of the current session.
      */
@@ -379,6 +384,7 @@ public abstract class AbstractJCRTest extends JUnitTest {
         mixSimpleVersionable = superuser.getNamespacePrefix(NS_MIX_URI) + ":simpleVersionable";
         mixLockable = superuser.getNamespacePrefix(NS_MIX_URI) + ":lockable";
         mixShareable = superuser.getNamespacePrefix(NS_MIX_URI) + ":shareable";
+        mixTitle = superuser.getNamespacePrefix(NS_MIX_URI) + ":title";
         ntQuery = superuser.getNamespacePrefix(NS_NT_URI) + ":query";
 
         // setup custom namespaces
@@ -722,6 +728,16 @@ public abstract class AbstractJCRTest extends JUnitTest {
         }
     }
 
+    /**
+     * Checks that the repository supports locking, otherwise aborts with
+     * {@link NotExecutableException}.
+     * @throws NotExecutableException when the repository does not support locking
+     */
+    protected void ensureLockingSupported() throws RepositoryException, NotExecutableException {
+        if (!isSupported(Repository.OPTION_LOCKING_SUPPORTED)) {
+            throw new NotExecutableException("This repository does not support locking.");
+        }
+    }
 
     private boolean canSetProperty(NodeType nodeType, String propertyName, int propertyType, boolean isMultiple) {
         PropertyDefinition propDefs[] = nodeType.getPropertyDefinitions();
