@@ -40,6 +40,7 @@ import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpUriRequest;
 import org.apache.http.entity.ContentType;
 import org.apache.http.entity.mime.FormBodyPart;
+import org.apache.http.entity.mime.HttpMultipartMode;
 import org.apache.http.entity.mime.MultipartEntityBuilder;
 import org.apache.http.message.BasicNameValuePair;
 import org.apache.jackrabbit.JcrConstants;
@@ -380,8 +381,8 @@ public class RepositoryServiceImpl extends org.apache.jackrabbit.spi2dav.Reposit
                     throw ExceptionConverter.generate(new DavException(statusCode, "Unable to retrieve NodeInfo for " + uri), request);
                 }
             } catch (IOException e) {
-                log.error("Internal error while retrieving NodeInfo.",e);
-                throw new RepositoryException(e.getMessage());
+                log.error("Internal error while retrieving NodeInfo for " + uri + ".", e);
+                throw new RepositoryException(e.getMessage(), e);
             } finally {
                 request.releaseConnection();
             }
@@ -438,8 +439,8 @@ public class RepositoryServiceImpl extends org.apache.jackrabbit.spi2dav.Reposit
                 return super.getPropertyInfo(sessionInfo, propertyId);
             }
         } catch (IOException e) {
-            log.error("Internal error while retrieving ItemInfo.",e);
-            throw new RepositoryException(e.getMessage());
+            log.error("Internal error while retrieving ItemInfo for " + uri + ".", e);
+            throw new RepositoryException(e.getMessage(), e);
         } catch (DavException e) {
             throw ExceptionConverter.generate(e);
         } finally {
@@ -615,7 +616,8 @@ public class RepositoryServiceImpl extends org.apache.jackrabbit.spi2dav.Reposit
             // engine has a form-size restriction (JCR-3726)
             Utils.addPart(PARAM_DIFF, buf.toString(), parts);
 
-            MultipartEntityBuilder b = MultipartEntityBuilder.create();
+            // JCR-4317: need RFC6532 mode so that values are encoded in UTF-8
+            MultipartEntityBuilder b = MultipartEntityBuilder.create().setMode(HttpMultipartMode.RFC6532);
             for (FormBodyPart p : parts) {
                 b.addPart(p.getName(), p.getBody());
             }
